==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/enums/ClassificationPrimaryMetrics.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Primary metric for Text-Classification task.
 */
public enum class ClassificationPrimaryMetrics(
    public val javaValue:
    com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics> {
    /**
     * AUC is the Area under the curve.
     * This metric represents arithmetic mean of the score for each class,
     * weighted by the number of true instances in each class.
     */
    AUCWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.AUCWeighted),

    /**
     * Accuracy is the ratio of predictions that exactly match the true class labels.
     */
    Accuracy(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.Accuracy),

    /**
     * Normalized macro recall is recall macro-averaged and normalized, so that random
     * performance has a score of 0, and perfect performance has a score of 1.
     */
    NormMacroRecall(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.NormMacroRecall),

    /**
     * The arithmetic mean of the average precision score for each class, weighted by
     * the number of true instances in each class.
     */
    AveragePrecisionScoreWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.AveragePrecisionScoreWeighted),

    /**
     * The arithmetic mean of precision for each class, weighted by number of true instances in each class.
     */
    PrecisionScoreWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.PrecisionScoreWeighted),
    ;

    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics):
            ClassificationPrimaryMetrics =
            ClassificationPrimaryMetrics.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/enums/ClassificationPrimaryMetrics.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Primary metric for Text-Classification task.
 */
public enum class ClassificationPrimaryMetrics(
    public val javaValue: com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics> {
    /**
     * AUC is the Area under the curve.
     * This metric represents arithmetic mean of the score for each class,
     * weighted by the number of true instances in each class.
     */
    AUCWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.AUCWeighted),

    /**
     * Accuracy is the ratio of predictions that exactly match the true class labels.
     */
    Accuracy(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.Accuracy),

    /**
     * Normalized macro recall is recall macro-averaged and normalized, so that random
     * performance has a score of 0, and perfect performance has a score of 1.
     */
    NormMacroRecall(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.NormMacroRecall),

    /**
     * The arithmetic mean of the average precision score for each class, weighted by
     * the number of true instances in each class.
     */
    AveragePrecisionScoreWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.AveragePrecisionScoreWeighted),

    /**
     * The arithmetic mean of precision for each class, weighted by number of true instances in each class.
     */
    PrecisionScoreWeighted(com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics.PrecisionScoreWeighted),
    ;

    override fun toJava(): com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.enums.ClassificationPrimaryMetrics): ClassificationPrimaryMetrics =
            ClassificationPrimaryMetrics.values().first { it.javaValue == javaType }
    }
}
